==> tine20-tinebase_2016.11.24.tar.bz2: Addressbook/js/Addressbook-lang-pt_BR-debug.js <==
/********************** tine translations of Addressbook**********************/ 
Locale.Gettext.prototype._msgs['./LC_MESSAGES/Addressbook'] = new Locale.Gettext.PO(({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2016-03-17 10:50+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Informação Comercial do Contato"

, "Organisation / Unit"
: "Organização / Unidade"

, "Business Address"
: "Endereço Comercial"

, "Email"
: "Email"

, "Telephone Work"
: "Telefone de trabalho"

, "Telephone Cellphone"
: "Telefone Celular"

, "Telephone Car"
: "Telefone do Carro"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Página do Telefone"

, "URL"
: "URL"

, "Role"
: "Perfil"

, "Room"
: "Sala"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefone do Assistente"

, "Private Contact Data"
: "Informação Pessoal do Contato"

, "Private Address"
: "Endereço Particular"

, "Email Home"
: "Email Residencial"

, "Telephone Home"
: "Telefone Residencial"

, "Telephone Cellphone Private"
: "Telefone Celuar Particular"

, "Telephone Fax Home"
: "Fax Residencial"

, "URL Home"
: "URL Residencial"

, "Other Data"
: "Outras Informações"

, "Birthday"
: "Aniversário"

, "Job Title"
: "Título do Trabalho"

, "Dear Mister"
: ""

, "Dear Miss"
: ""

, "Dear"
: ""

, "Mister"
: ""

, "Misses"
: ""

, "%s's personal addressbook"
: "%s's caderno de endereço pessoal"

, "Lists"
: "Listas"

, "List Roles"
: ""

, "manage shared addressbooks"
: "gerencie Catálogos de Endereços compartilhados"

, "Create new shared addressbook folders"
: "Criar novas pastas compartilhadas no Catálogo de Endereços"

, "manage shared addressbook favorites"
: "gerenciar os favoritos compartilhados do Catálogo de Endereços"

, "Create or update shared addressbook favorites"
: "Criar ou atualizar favoritos compartilhados no Caderno de Endereços"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list roles in CoreData"
: ""

, "View, create, delete or update list roles in CoreData application"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "CardDAV URL"
: "URL do CardDAV"

, "Contact, Contacts"
: [
  "Contato"
 ,"Contatos"

]
, "List Role, , n); gettext("
: [
  ""
 ,""

]
, "Members"
: "Membros"

, "Remove Member"
: ""

, "Map"
: "Mapa"

, "Personal Information"
: "Informação Pessoal"

, "Salutation"
: "Saudação"

, "Title"
: "Título"

, "First Name"
: "Prenome"

, "Middle Name"
: "Nome do Meio"

, "Last Name"
: "Sobrenome"

, "Company"
: "Empresa"

, "Unit"
: "Unidade"

, "Suffix"
: "Sufixo"

, "Job Role"
: "Função"

, "Display Name"
: "Exibir Nome"

, "Contact Information"
: "Informação de Contato"

, "Phone"
: "Telefone"

, "Mobile"
: "Celular"

, "Fax"
: "Fax"

, "Phone (private)"
: "Telefone (particular)"

, "Mobile (private)"
: "Celular (particular)"

, "Fax (private)"
: "Fax (particular)"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "-mail (particular)"

, "Web"
: "Web"

, "Company Address"
: "Endereço da Empresa"

, "Street"
: "Rua"

, "Street 2"
: "Rua 2"

, "Region"
: "Estado"

, "Postal Code"
: "Código Postal"

, "City"
: "Cidade"

, "Country"
: "País"

, "Description"
: "Descrição"

, "Enter description"
: "Informar descrição"

, "Export as pdf"
: "Exportar como pdf"

, "Parse address"
: "Analisar endereço"

, "Paste address"
: "Colar endereço"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: "O endereço não pode ser lido"

, "End token mode"
: "Finalizar o modo de símbolos"

, "New Contact"
: "Novo Contato"

, "Addressbook, Addressbooks"
: [
  "Catálogo de Endereço"
 ,"Catálogo de Endereços"

]
, "ID"
: ""

, "Name"
: "Nome"

, "Member of List"
: "Membro da Lista (Endereço Comercial)"

, "Street (Company Address)"
: "Rua (Endereço Comercial)"

, "Street 2 (Company Address)"
: "Rua 2 (Endereço Comercial)"

, "City (Company Address)"
: "Cidade (Endereço Comercial)"

, "Region (Company Address)"
: "Municipio (Endereço Comercial)"

, "Postal Code (Company Address)"
: "Código Postal (Endereço Comercial)"

, "Country (Company Address)"
: "País (Endereço Comercial)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "Rua (Endereço Privado)"

, "Street 2 (Private Address)"
: "Rua 2 (Endereço Privado)"

, "City (Private Address)"
: "Cidade (Endereço Privado)"

, "Region (Private Address)"
: "Município (Endereço Privado)"

, "Postal Code (Private Address)"
: "Código Postal (Endereço Particular)"

, "Country (Private Address)"
: "País (Endereço Particular)"

, "Company Communication"
: "Companhia de Comunicação"

, "Private Communication"
: "Comunicação Particular"

, "Web (private)"
: "Web (particular)"

, "Contacts"
: "Contatos"

, "Addressbooks"
: "Catálogo de Endereços"

, "User Account"
: "Conta do Usuário"

, "Quick Search"
: "Busca Rápida"

, "Type"
: "Tipo"

, "Last Modified Time"
: "Hora do Último Modificaco"

, "Last Modified By"
: "Último Modificado Por"

, "Creation Time"
: "Hora da Criação"

, "Created By"
: "Criado Por"

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Quick search"
: "Busca rápida"

, "Email Address, Email Addresses"
: [
  ""
 ,""

]
, "Email Addresses"
: ""

, "Select list"
: ""

, "List type"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "List Information"
: ""

, "{0} must be given"
: ""

, "Company address"
: "Endereço da Empresa"

, "Private address"
: "Endereço particular"

, "Select contact"
: "Selecionar contato"

, "Private"
: "Particular"

, "Info"
: "Info"

, "Insecure link"
: "Ligação insegura"

, "Please review this link in edit dialog."
: "Favor revisar esta ligação no diálogo editado."

, "Export {0}, Export {0}"
: [
  "Exportar {0}"
 ,"Exportar {0}"

]
, "Export as PDF"
: "Exportar como PDF"

, "Export as CSV"
: "Exportar como CSV"

, "Export as ODS"
: "Exportar como ODS"

, "Export as XLS"
: "Exportar como XLS"

, "Export as DOC"
: "Exportar como DOC"

, "Export as ..."
: "Exportar como ..."

, "Import contacts"
: "Importar contatos"

, "Contact of a user account"
: "Contado da conta do usuário"

, "No name"
: ""

, "Tags"
: "Identificações"

, "Full Name"
: "Nome Completo"

, "Postalcode"
: "Código Postal"

, "Street (private)"
: "Rua (particular)"

, "City (private)"
: "Cidade (particular)"

, "Region (private)"
: "Município (particular)"

, "Postalcode (private)"
: "Código postal (particular)"

, "Country (private)"
: "País (particular)"

, "Car phone"
: "Telefone do carro"

, "Pager"
: "Pager"

, "Email (private)"
: "Email (particular)"

, "URL (private)"
: "URL (particular)"

, "Note"
: "Lembrete"

, "Timezone"
: "Fuso horário"

, "Geo"
: "Geo"

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Uploaded new contact image."
: "Nova imagem de contato carregada."

, "All contacts"
: "Todos os contatos"

, "Default Addressbook"
: "Catálogo de Endereços Padrão"

, "The default addressbook for new contacts"
: "O Catálogo de Endereços padrão para novos contatos"

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on addressbook startup"
: "Meu favorito padrão que é carregado no Catálogo de Endereços no começo"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "This contact has been automatically added by the system as an event attender"
: "Este contato foi automaticamente adicionado pelo sistema como um participante do evento"

, "All Contacts"
: "Todos Contatos"

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee)"
: ""

, "Contact duplicate check fields"
: "Contato dupliado: verifique as informações"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Esses campos foram verificados quando o novo contato foi criado.  Se o registro com o a mesma informação for encontrado, uma exceção de duplicata é exibida."

, "Contact salutations available"
: "Saudações de Contato disponível"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saudações de contatos possíveis. Note que valores adicionais poderiam impactar em Catálogos de Endereços de outros sistemas durante a exportação ou sincronização."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Regras de análise para endereços"

, "Path to a XML file with address parsing rules."
: "Caminho para o arquivo XML com regras de análise de endereço"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Arquivo CSV do Outlook 2007 em Alemão"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatos importados em ###CURRENTDATE### na ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importação de arquivo CSV do livro de endereços do Outlook"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importação de contato do livro de endereços do Google"

, "Contact CSV import from mac address book"
: "Importação de contato do livro de endereços do Mac"

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importação de contato do VCARD"

, "Internal Contacts"
: "Contatos Internos"

, "All contacts I have read grants for"
: "Todos os contatos que eu marquei como privilégio"

, "My company"
: "Minha empresa"

, "All coworkers in my company"
: "Todos os colegas de trabalho na minha empresa"

, "My contacts"
: "Meus contatos"

, "All contacts in my Addressbooks"
: "Todos os contatos no meu Caderno de Endereço"

, "Last modified by me"
: "Último modificado por mim"

, "All contacts that I have last modified"
: "Todos os contatos que eu modifiquei por último"

, "Contact"
: "Contato"

, "List Role"
: ""

, "Addressbook"
: "Catálogo de Endereço"

, "List"
: "Lista"

, "Email Address"
: ""

, "Export {0}"
: "Exportar {0}"

}));

==> tine20-tinebase_2019.11.25.tar.bz2: Addressbook/js/Addressbook-lang-pt_BR-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Portuguese (Brazil) (http://www.transifex.com/tine20/tine20/language/pt_BR/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: pt_BR\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "Informação Comercial do Contato"

, "Organisation / Unit"
: "Organização / Unidade"

, "Business Address"
: "Endereço Comercial"

, "Email"
: "Email"

, "Telephone Work"
: "Telefone de trabalho"

, "Telephone Cellphone"
: "Telefone Celular"

, "Telephone Car"
: "Telefone do Carro"

, "Telephone Fax"
: "Fax"

, "Telephone Page"
: "Página do Telefone"

, "URL"
: "URL"

, "Role"
: "Perfil"

, "Room"
: "Sala"

, "Assistant"
: "Assistente"

, "Assistant Telephone"
: "Telefone do Assistente"

, "Private Contact Data"
: "Informação Pessoal do Contato"

, "Private Address"
: "Endereço Particular"

, "Email Home"
: "Email Residencial"

, "Telephone Home"
: "Telefone Residencial"

, "Telephone Cellphone Private"
: "Telefone Celuar Particular"

, "Telephone Fax Home"
: "Fax Residencial"

, "URL Home"
: "URL Residencial"

, "Other Data"
: "Outras Informações"

, "Birthday"
: "Aniversário"

, "Job Title"
: "Título do Trabalho"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "Lista"
 ,"Listas"

]
, "Percent"
: ""

, "Description"
: "Descrição"

, "Members"
: "Membros"

, "Type"
: "Tipo"

, "List type"
: "Listar tipo"

, "Addressbook, Addressbooks"
: [
  "Catálogo de Endereço"
 ,"Catálogo de Endereços"

]
, "Contact, Contacts"
: [
  "Contato"
 ,"Contatos"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "País"

, "City"
: "Cidade"

, "Postalcode"
: "Código Postal"

, "Region"
: "Estado"

, "Street"
: "Rua"

, "Street 2"
: "Rua 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "País (particular)"

, "City (private)"
: "Cidade (particular)"

, "Postalcode (private)"
: "Código postal (particular)"

, "Region (private)"
: "Município (particular)"

, "Street (private)"
: "Rua (particular)"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "Email (particular)"

, "Free/Busy URI"
: ""

, "Geo"
: "Geo"

, "Groups"
: "Grupos"

, "Industry, Industries"
: [
  "Indústrias"
 ,"Indústrias"

]
, "Note"
: "Lembrete"

, "Last Name"
: "Sobrenome"

, "Display Name"
: "Exibir Nome"

, "Full Name"
: "Nome Completo"

, "First Name"
: "Prenome"

, "Middle Name"
: "Nome do Meio"

, "Title"
: "Título"

, "Suffix"
: "Sufixo"

, "Company"
: "Empresa"

, "Unit"
: "Unidade"

, "Paths"
: ""

, "Preferred Address"
: "Endereço Preferido"

, "Job Role"
: "Função"

, "Salutation"
: "Saudação"

, "syncBackendIds"
: ""

, "Car phone"
: "Telefone do carro"

, "Mobile"
: "Celular"

, "Mobile (private)"
: "Celular (particular)"

, "Fax"
: "Fax"

, "Fax (private)"
: "Fax (particular)"

, "Phone (private)"
: "Telefone (particular)"

, "Pager"
: "Pager"

, "Phone"
: "Telefone"

, "Timezone"
: "Fuso horário"

, "Web"
: "Web"

, "URL (private)"
: "URL (particular)"

, "Label"
: ""

, "Lists"
: "Listas"

, "Select list"
: "Selecionar lista"

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: "Campos personalizados"

, "Related to"
: "Relacionado a"

, "Contact Information"
: "Informação de Contato"

, "Company Address"
: "Endereço da Empresa"

, "New Contact"
: "Novo Contato"

, "ID"
: "ID"

, "Name"
: "Nome"

, "Structure, Structures"
: [
  ""
 ,""

]
, "Resources"
: ""

, "Import contacts"
: "Importar contatos"

, "Contact of a user account"
: "Contado da conta do usuário"

, "No name"
: "Sem nome"

, "Business"
: "Negócios"

, "Private"
: "Particular"

, "Not set"
: "Não configurado"

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "Identificações"

, "List Roles"
: ""

, "Street (Company Address)"
: "Rua (Endereço Comercial)"

, "Street 2 (Company Address)"
: "Rua 2 (Endereço Comercial)"

, "City (Company Address)"
: "Cidade (Endereço Comercial)"

, "Region (Company Address)"
: "Municipio (Endereço Comercial)"

, "Postal Code (Company Address)"
: "Código Postal (Endereço Comercial)"

, "Country (Company Address)"
: "País (Endereço Comercial)"

, "Longitude (Company Address)"
: "Longitude (Endereço da Empresa)"

, "Latitude (Company Address)"
: "Latitude (Endereço da Empresa)"

, "Street (Private Address)"
: "Rua (Endereço Privado)"

, "Street 2 (Private Address)"
: "Rua 2 (Endereço Privado)"

, "City (Private Address)"
: "Cidade (Endereço Privado)"

, "Region (Private Address)"
: "Município (Endereço Privado)"

, "Postal Code (Private Address)"
: "Código Postal (Endereço Particular)"

, "Country (Private Address)"
: "País (Endereço Particular)"

, "Company Communication"
: "Companhia de Comunicação"

, "Private Communication"
: "Comunicação Particular"

, "E-Mail"
: "E-mail"

, "E-Mail (private)"
: "-mail (particular)"

, "Web (private)"
: "Web (particular)"

, "Contacts"
: "Contatos"

, "Addressbooks"
: "Catálogo de Endereços"

, "User Account"
: "Conta do Usuário"

, "Quick Search"
: "Busca Rápida"

, "Postal Code"
: "Código Postal"

, "Last Modified Time"
: "Hora do Último Modificaco"

, "Last Modified By"
: "Último Modificado Por"

, "Creation Time"
: "Hora da Criação"

, "Created By"
: "Criado Por"

, "Email Address, Email Addresses"
: [
  "Endereços de e-mail"
 ,"Endereços de e-mail"

]
, "Email Addresses"
: "Endereços de e-mail"

, "Quick search"
: "Busca rápida"

, "List Function, List Functions"
: [
  "Listar Funções"
 ,"Listar Funções"

]
, "List Functions"
: "Listar Funções"

, "Industries"
: "Indústrias"

, "Structures"
: ""

, "List Information"
: "Listar Informação"

, "Enter description"
: "Informar descrição"

, "{0} must be given"
: "{0} deve ser fornecido"

, "Member of List"
: "Membro da Lista (Endereço Comercial)"

, "Map"
: "Mapa"

, "Company address"
: "Endereço da Empresa"

, "Private address"
: "Endereço particular"

, "CardDAV URL"
: "URL do CardDAV"

, "Search for system groups ..."
: "Busca por grupos de sistema..."

, "Search for groups ..."
: "Busca por grupos..."

, "Personal Information"
: "Informação Pessoal"

, "Parse address"
: "Analisar endereço"

, "Print contact"
: "Imprime contato"

, "Paste address"
: "Colar endereço"

, "Please paste an address or a URI to a vcard that should be parsed:"
: "Por favor, cole um endereço ou um URI para um vcard que deve ser processado"

, "Failed to parse address!"
: "Falha em processar endereço!"

, "The address could not be read."
: "O endereço não pode ser lido"

, "End token mode"
: "Finalizar o modo de símbolos"

, "Remove Member"
: "Remover Membro"

, "Emails"
: "Emails"

, "System Group"
: "Grupo de Sistema"

, "Group"
: "Grupo"

, "Search for users ..."
: "Buscar por usuários..."

, "Search for Contacts ..."
: "Buscar por Contatos"

, "All contacts"
: "Todos os contatos"

, "Default Addressbook"
: "Catálogo de Endereços Padrão"

, "The default addressbook for new contacts"
: "O Catálogo de Endereços padrão para novos contatos"

, "Default Favorite"
: "Favorito Padrão"

, "The default favorite which is loaded on addressbook startup"
: "Meu favorito padrão que é carregado no Catálogo de Endereços no começo"

, "Contacts ODS export configuration"
: "Configuração de exportação de Contatos para ODS"

, "Use this configuration for the contact ODS export."
: "Usar esta configuração para a exportação do contato para ODS"

, "Contacts XLS export configuration"
: "Configuração de exportação de contatos para XLS"

, "Use this configuration for the contact XLS export."
: "Usar esta configuração para a exportação do contato para XLS"

, "default"
: "padrão"

, "All Contacts"
: "Todos Contatos"

, "This contact has been automatically added by the system as an event attender"
: "Este contato foi automaticamente adicionado pelo sistema como um participante do evento"

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "Contato dupliado: verifique as informações"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "Esses campos foram verificados quando o novo contato foi criado.  Se o registro com o a mesma informação for encontrado, uma exceção de duplicata é exibida."

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "Saudações de Contato disponível"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "Saudações de contatos possíveis. Note que valores adicionais poderiam impactar em Catálogos de Endereços de outros sistemas durante a exportação ou sincronização."

, "Mr"
: "Sr"

, "Ms"
: "Sra"

, "Parsing rules for addresses"
: "Regras de análise para endereços"

, "Path to a XML file with address parsing rules."
: "Caminho para o arquivo XML com regras de análise de endereço"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "Importação de contato do VCARD"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: "Importar lista (###CURRENTDATE###)"

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: "Contatos importados em ###CURRENTDATE### na ###CURRENTTIME### por ###USERFULLNAME###"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "Arquivo CSV do Outlook 2007 em Alemão"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "Importação de arquivo CSV do livro de endereços do Outlook"

, "Contact CSV import from mac address book"
: "Importação de contato do livro de endereços do Mac"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "Importação de contato do livro de endereços do Google"

, "manage shared addressbooks"
: "gerencie Catálogos de Endereços compartilhados"

, "Create new shared addressbook folders"
: "Criar novas pastas compartilhadas no Catálogo de Endereços"

, "manage shared addressbook favorites"
: "gerenciar os favoritos compartilhados do Catálogo de Endereços"

, "Create or update shared addressbook favorites"
: "Criar ou atualizar favoritos compartilhados no Caderno de Endereços"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "%s's personal addressbook"
: "%s's caderno de endereço pessoal"

, "All contacts I have read grants for"
: "Todos os contatos que eu marquei como privilégio"

, "My company"
: "Minha empresa"

, "All coworkers in my company"
: "Todos os colegas de trabalho na minha empresa"

, "My contacts"
: "Meus contatos"

, "All contacts in my Addressbooks"
: "Todos os contatos no meu Caderno de Endereço"

, "Last modified by me"
: "Último modificado por mim"

, "All contacts that I have last modified"
: "Todos os contatos que eu modifiquei por último"

, "Internal Contacts"
: "Contatos Internos"
, ""
: "Project-Id-Version: Tine 2.0 - GDPR\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2008-07-29 21:14+0100\nLast-Translator: Cornelius Weiss <c.weiss@metaways.de>\nLanguage-Team: Tine 2.0 Translators\nLanguage: \nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nX-Poedit-Language: Portuguese\nX-Poedit-Country: BRAZIL\nX-Poedit-SourceCharset: utf-8\nPlural-Forms: nplurals=2; plural=n != 1;\n"

, "Data provenances"
: ""

, "Data intended purposes"
: ""

, "Show expired"
: ""

, "Data Provenance"
: ""

, "Reason for Editing"
: ""

, "Please enter the reason for editing this data"
: ""

, "Please Confirm the Data Provenance"
: ""

, "GDPR"
: ""

, "Must not be contacted"
: ""

, "This Contact withdrawed usage of his data for any purpose."
: ""

, "Blacklist"
: ""

, "GDPR Intended Purpose"
: ""

, "GDPR Blacklisted"
: ""

, "GDPR Data Provenance"
: ""

, "GDPR Data Editing Reason"
: ""

, "Data provenance for ADB contacts mandatory"
: ""

, "Whether the data provenance for ADB contacts is mandatory, not mandatory or empty provenances will be set to a default"
: ""

, "yes"
: ""

, "no"
: ""

, "default"
: ""

, "Default data provenance for ADB contacts"
: ""

, "Data intended purpose, Data intended purposes"
: [
  ""
 ,""

]
, "Agreement date"
: ""

, "Agreement comment"
: ""

, "Withdraw date"
: ""

, "Withdraw comment"
: ""

, "Data provenance, Data provenances"
: [
  ""
 ,""

]
, "Expiration"
: ""

, "Manage data provenances in CoreData"
: ""

, "View, create, delete or update data provenances in CoreData application"
: ""

, "Manage data intended purposes in CoreData"
: ""

, "View, create, delete or update data intended purposes in CoreData application"
: ""

, "List"
: "Lista"

, "Addressbook"
: "Catálogo de Endereço"

, "Contact"
: "Contato"

, "Industry"
: "Indústrias"

, "Structure"
: ""

, "Email Address"
: "Endereços de e-mail"

, "List Function"
: "Listar Funções"

, "Relation"
: ""

, "Data intended purpose"
: ""

, "Data provenance"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
